#!/usr/bin/ksh
#   begin_generated_IBM_prolog                                          
#                                                                       
#   prolog.pro.samp.telcosp                                                 
#   ******************************************************************  
#   IBM Sample Source Materials                                         
#                                                                       
#   Sample source materials are supplied As-Is.                         
#   No warranty is expressed or implied.                                
#                                                                       
#   Product(s): 5724-O05                                             
#                                                                       
#   Copyright IBM Corp. 2000, 2009                                      
#                                                                       
#   The source code for this program supplied under the terms of the    
#   End User License Agreement (EULA) that accompanied this product.    
#   ******************************************************************  
#                                                                       
#   end_generated_IBM_prolog                                        

#------------------------------------------------------------------
# Create the IBM DB2 database tables
# Version: 1.7.1.4
#
# Set/gather default information, then prompt user to verify
# or override values.
#
# To debug this script change the first line to
# "#!/usr/bin/ksh -x" or "#!/usr/bin/ksh -v".
# You may also want to comment out any "clear" commands in the
# script.
#------------------------------------------------------------------

#------------------------------------------------------------------
# Get the DB2 instance id and connection port from /etc/services.
# This information will be contained in the frst two strings on the
# line that contains "db2c".  This line was automatically added to
# /etc/services by the DB2 installation program.
# Example:
#   db2cdb2inst1    50000/tcp   # Connection port for DB2 instance db2inst1
#------------------------------------------------------------------


function getDBInfo {

  ((index=0))
  for stringValue in `cat /etc/services | grep db2c`
    do
      ((index=index + 1))
      [[ $index = "1" ]] && dbInstance=${stringValue#db2c}   # strip "db2c" from beginning
      [[ $index = "2" ]] && dbPort=${stringValue%/tcp}       # strip "/tcp" from end
      # print "index = " $index ", stringValue = " $stringValue ",dbInstance = " $dbInstance ",dbPort = " $dbPort
    done

  # some systems use 'db2c_' instead of just 'db2c', so we check twice
  ((index=0))
  for stringValue in `cat /etc/services | grep db2c_`
    do
      ((index=index + 1))
      [[ $index = "1" ]] && dbInstance=${stringValue#db2c_}   # strip "db2c" from beginning
      [[ $index = "2" ]] && dbPort=${stringValue%/tcp}        # strip "/tcp" from end
      # print "index = " $index ", stringValue = " $stringValue ",dbInstance = " $dbInstance ",dbPort = " $dbPort
    done

} # end of function getDBInfo

#------------------------------------------------------------------
# Display information to user
#------------------------------------------------------------------

function displayGUI {

  #clear
  print "Usage: ConfigDB2.sh dbServer dbPort dbName dbAlias dbLocale"
  print "                    dbInstance dbInstancePW dbUser dbUserPW"
  print "                    ddlFile dbDir dbCreate menuflag"
  print "These values will be used to create the database."
  print "Each value must be filled in."
  print "Press Enter to accept these values and continue, otherwise"
  print "  enter the number of the parameter you wish to override."
  print "The menuflag should be set to TRUE to display the menu."
  print ""
  print "   1. Database server hostname (dbServer)......: " $dbServer
  print "   2. Database server connection port (dbPort).: " $dbPort
  print "   3. Database name (dbName)...................: " $dbName
  print "      Recommended Value: WPS_DB"
  print "   4. Database alias (dbAlias).................: " $dbAlias
  print "      Recommended Value: WPS_AL"
  print "   5. Database locale (dbLocale)...............: " $dbLocale
  print "      Recommended Value: US"
  print "   6. Database server instance id (dbInstance).: " $dbInstance
  print "   7. Database server instance password (dbInstancPW).: " $dbInstancePW
  print "   8. Database userid (dbUser).................: " $dbUser
  print "   9. Database userid password (dbUserPW)......: " $dbUserPW
  print "  10. Path and file name of DDL file (ddlFile).: " $ddlFile
  print "  11. New database directory (dbDir)...........: " $dbDir
  print "      Recommended Value: /usr/srvspace"
  print "  12. Database (re)create (dbCreate)...........: " $dbCreate
  print "      Recommended Value: TRUE"
  print ""

  read input
  # [[ $input = "" ]] && rc="0" || rc=$input

  # rc must be an integer value.  Correct it if a typo was made.
  case $input in
    1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12 ) rc=$input ;;   # numeric input
    ""               ) rc="0"    ;;   # null input
    *                ) rc=88     ;;   # string input which cannot be passed by return command
  esac
  return $rc

} # end of function displayGUI

#------------------------------------------------------------------
# Program main code
#------------------------------------------------------------------

getDBInfo
# dont comment out this information it is important to the user
print "Database Connection Information: dbInstance " $dbInstance " dbPort " $dbPort

# process menu
dbServer=$1
dbPort=$2
dbName=$3
dbAlias=$4
dbLocale=$5
dbInstance=$6
dbInstancePW=$7
dbUser=$8
dbUserPW=$9
ddlFile=${10}
dbDir=${11}
dbCreate=${12}
menuflag=${13}

# handle menuflag not specified
if [[ -z $menuflag ]]
   then
      menuflag="TRUE"
fi 

if [[ -z $dbName ]]
   then 
      dbName="WPS_DB"
fi

if [[ -z $dbAlias ]]
   then 
      dbAlias="WPS_AL"
fi

if [[ -z $dbLocale ]]
   then
      dbLocale="US"
fi

if [[ -z $dbDir ]]
   then 
      dbDir="/usr/srvspace"
fi

if [[ -z $dbCreate ]]
   then
      dbCreate="TRUE"
fi

if [[ "$menuflag" = "TRUE" || "$menuflag" = "true" ]]
   then

   ((rc=99))
   while ((rc != 0))
     do
       #[[ -e "$ddlFile" ]] || ((rc=10))
       case $rc in
         1) print "    Enter the database server's hostname:"
            read input
            [[ -n $input ]] && dbServer=$input
            ;;

         2) print "    Enter the database server's connection port:"
            read input
            [[ -n $input ]] && dbPort=$input
            ;;

         3) print "    Enter the database name:"
            read input
            [[ -n $input ]] && dbName=$input
            ;;

         4) print "    Enter the database alias:"
            read input
            [[ -n $input ]] && dbAlias=$input
            ;;

         5) print "    This is the territory code used by the database to control sort order"
            print "      and other reginal settings.  Examples are US, JP, CN, TW, Lat, etc."
            print "    Enter the database territory code:"
            read input
            [[ -n $input ]] && dbLocale=$input
            ;;

         6) print "    Enter the database server's instance id:"
            read input
            [[ -n $input ]] && dbInstance=$input
            ;;

         7) print "    Enter the database server's instance id's password:"
            read input
            [[ -n $input ]] && dbInstancePW=$input
            ;;

         8) print "    Enter the database server's userid:"
            read input
            [[ -n $input ]] && dbUser=$input
            ;;

         9) print "    Enter the database server's userid's password:"
            read input
            [[ -n $input ]] && dbUserPW=$input
            ;;

        10) print "    Enter the path and file name of the DDL file:"
            print "    This value must be correct before any other values can be changed."
            print "    Recommended value is the DDL file provided with the component"
            read input
            if [[ -n $input ]]; then
            	ddlFile=$input
            else
            	ddlFile=""
            fi		
            ;;
        11) print "    Enter the path to the directory to create database and tablespace in:"
            print "    The db user must have permission to create and write in this directory."
            read input
            [[ -n $input ]] && dbDir=$input
            ;;
        12) print "    Enter the boolean indicating whether to (re)create the database (TRUE or FALSE):"
            read input
            [[ -n $input ]] && dbCreate=$input
            ;;
                                                                                                                                                                    
         *)
           ;;
       esac

       if [[ -s $ddlFile || -z $ddlFile ]]
       then
         displayGUI
       else    # request location of the ddl again
         print "    ERROR: Cannot find file $ddlFile"
         print "      ensure you include the path information to the DDL file"
         ((rc=10))
       fi

     done  # end of while loop
fi     # end of menuing block

if [[ "TRUE" = "$dbCreate" || "true" = "$dbCreate" ]]
    then
          print "Creating server database."

          # This command may be necessary if the database is in use.
          #db2 force applications all

          db2 uncatalog database $dbAlias

          # This command may be necessary if the database already exists in either
          # the local database directory or system database directory.
          # db2 catalog database $dbName

          # Execute the then block if the DB2 server is local.
          # Execute the else block if the DB2 server is remote, as in a cluster.
          if [[ `hostname` = $dbServer ]]
            then
              db2 drop database $dbName
              db2 uncatalog node local
              db2 create database $dbName using codeset UTF-8 territory $dbLocale with \"WebSphere TWSS Data\"
              db2 catalog tcpip node local remote $dbServer server $dbPort
              db2 catalog database $dbName as $dbAlias at node local
            else
              db2 uncatalog node $dbServer
              db2 catalog tcpip node $dbServer remote $dbServer server $dbPort
              db2 catalog database $dbName as $dbAlias at node $dbServer with \"WebSphere TWSS Data\"
          fi

          db2 connect to $dbAlias user $dbInstance using $dbInstancePW
	  if [[ $dbUser != $dbInstance ]]
            then
              db2 grant DBADM on database to user $dbUser
          fi
		  
	  #################################################################
          #   All columns (except CLOBs and BLOBs) must fit within the page size
          #   (default is 4K).  So if you need to increase column sizes, you may
          #   have to place the table in a tablespace with a larger page size.
          #   See the DB2 Administrator Guide for a more detailed explaination of
          #   the design rules and the DB2 SQL Reference for details of the
          #   command syntax.
          #
          #   ****************************************************************
          #   Creating an 8K-buffer pool and 8K-tablespaces
          #
	  #   If you need to increase the maximum page size, to 16K or 32K,
	  #   be SURE to do a global change in this file !!! 
          #   You can change the names of 'st8kbp' and 'st8kts' to any valid name.
 	  #   *****  Important  ****  Important  ****  Important  ****  Important **
          #   ** You will also need update the path in the tablespace command !!!
	  #################################################################
	  print "Creating directory for tablespace managing..."
	  mkdir -p -m 777 $dbDir/db2tbs/$dbName
	  mkdir -p -m 777 $dbDir/db2tbs/$dbName/st8ktemp
	  touch $dbDir/db2tbs/$dbName/st8k.ts
	  chmod 777 $dbDir/db2tbs/$dbName/st8k.ts
	  
	  db2 create bufferpool st8kbp size 10000 pagesize 8K
	  db2 create bufferpool st8ktempbp size 1000 pagesize 8K
	  line="db2 create tablespace st8kts pagesize 8k managed by system using ('$dbDir/db2tbs/$dbName/st8kts') extentsize 256 prefetchsize 64 bufferpool st8kbp"
          $line
	  line="db2 create temporary tablespace st8ktempts pagesize 8k managed by system using ('$dbDir/db2tbs/$dbName/st8ktemp') bufferpool st8ktempbp"
          $line

	  db2 alter bufferpool ibmdefaultbp size 10000
	  line="db2 create tablespace st4kts pagesize 4k managed by system using ('$dbDir/db2tbs/$dbName/st4kts') extentsize 256 prefetchsize 64 bufferpool ibmdefaultbp"
          $line
	  line="db2 create tablespace st4kts2 pagesize 4k managed by system using ('$dbDir/db2tbs/$dbName/st4kts2') extentsize 256 prefetchsize 64 bufferpool ibmdefaultbp"
          $line
	  ###################################################################
	  # The following DB2 tuning lines are added as required in the SPR #MJAN6PG85N
	  ###################################################################
          db2 update db cfg for $dbAlias using dbheap 8192
	  db2 update db cfg for $dbAlias using logbufsz 2048
	  db2 update db cfg for $dbAlias using app_ctl_heap_sz 4096
	  db2 update db cfg for $dbAlias using sortheap 512
	  db2 update db cfg for $dbAlias using applheapsz 2048
	  db2 update db cfg for $dbAlias using num_iocleaners 3
 	  db2 update db cfg for $dbAlias using logfilsiz 5000
	  db2 update db cfg for $dbAlias using logprimary 20
	  db2 update db cfg for $dbAlias using logsecond 20
	  db2 update db cfg for $dbAlias using auto_maint on
	  db2 update db cfg for $dbAlias using auto_tbl_maint on
	  db2 update db cfg for $dbAlias using auto_runstats on

	  db2 update db cfg for $dbAlias using MAXLOCKS 80 
	  db2 update db cfg for $dbAlias using LOCKTIMEOUT 60 
 	  db2 update db cfg for $dbAlias using LOCKLIST 10000 
	  db2 update db cfg for $dbAlias using MINCOMMIT 1 

	  db2 update db cfg for $dbAlias using NUM_IOCLEANERS 11 
	  db2 update db cfg for $dbAlias using NUM_IOSERVERS 10
	
          db2 connect reset
          db2 terminate
		
	  db2 update dbm cfg using health_mon off

	  db2stop
	  db2start
         
fi
    ########################################################################
    #
    #   *****  Important  ****  Important  ****  Important  ****  Important **
    #   If you are increasing the table row limit to 8K, then you
    #   will then need to add ' in SRVSPACE ' to the end of each 'create table'
    #   command that exists in the DDL file before running this script.
    #
    ########################################################################

if [[ -r "$ddlFile" ]];then
    # Now create the database tables. See the comment above regarding row size.
    db2 connect to $dbAlias user $dbUser using $dbUserPW

    # Tell DB2 to run the users DDL commands
    db2 -tvf $ddlFile

    db2 connect reset
    db2 terminate

  else
    print "ERROR: $ddlFile cannot be found or is not readable by this process.";
    exit
fi

print ""
print "= Note: ====================================================================="
print "  User "$dbUser" may has been granted DBADM authorities to database "$dbAlias"."
print ""
print "  You may want to revoke several of the authorities that have been granted."
print "  The user will require the authority necessary to access and update "$dbAlias"."
print ""
print "  To remove DBADM authority, issue the following commands:"
print "     db2 connect to "$dbAlias" user "$dbInstance
print "     db2 revoke DBADM,LOAD,IMPLICIT_SCHEMA on database from "$dbUser
print "     db2 revoke BINDADD,CREATE_NOT_FENCED on database from "$dbUser
print "     db2 terminate"
print ""
print ""
print "  $0 is complete."

exit
