#!/usr/bin/ksh
#   begin_generated_IBM_prolog                                          
#                                                                       
#   prolog.pro.samp.telcosp                                                 
#   ******************************************************************  
#   IBM Sample Source Materials                                         
#                                                                       
#   Sample source materials are supplied As-Is.                         
#   No warranty is expressed or implied.                                
#                                                                       
#   Product(s): 5724-O05                                             
#                                                                       
#   Copyright IBM Corp. 2000, 2009                                      
#                                                                       
#   The source code for this program supplied under the terms of the    
#   End User License Agreement (EULA) that accompanied this product.    
#   ******************************************************************  
#                                                                       
#   end_generated_IBM_prolog                                            

#------------------------------------------------------------------
# Create the Oracle database tables
# Version: 1.1.2.5
#
# Set/gather default information, then prompt user to verify
# or override values.
#
# To debug this script change the first line to
# "#!/usr/bin/ksh -x" or "#!/usr/bin/ksh -v".
# You may also want to comment out any "clear" commands in the
# script.
#------------------------------------------------------------------

#------------------------------------------------------------------
# Display information to user
#------------------------------------------------------------------


function displayGUI {

  #clear
  print "Usage: ConfigOracle.sh dbName dbUser dbUserPW ddlFile menuflag"
  print ""
  print "These values will be used to prepare the database."
  print "Each value must be filled in."
  print "Press Enter to accept these values and continue, otherwise"
  print "  enter the number of the parameter you wish to override."
  print "The menuflag should be set to TRUE to display the menu."
  print ""
  print "   1. Database name (dbName).............: " $dbName
  print "      Recommended Value: WPS_DB"
  print "   2. Database userid (dbUser)...........: " $dbUser
  print "   3. Database userid password (dbUserPW): " $dbUserPW
  print "   4. Data Definition file (ddlFile).....: " $ddlFile
  print ""

  read input
  # [[ $input = "" ]] && rc="0" || rc=$input

  # rc must be an integer value.  Correct it if a typo was made.
  case $input in
    1 | 2 | 3 | 4  ) rc=$input ;;   # numeric input
    ""               ) rc="0"    ;;   # null input
    *                ) rc=99     ;;   # string input which cannot be passed by return command
  esac
  return $rc

} # end of function displayGUI

#------------------------------------------------------------------
# Program main code
#------------------------------------------------------------------

# initialize command line parameters

dbName=$1
dbUser=$2
dbUserPW=$3
ddlFile=$4
menuflag=$5

# handle menuflag not specified
if [[ -z $menuflag ]]
   then
      menuflag="TRUE"
fi 

if [[ -z $dbName ]]
   then
      dbName="WPS_DB"
fi

# execute menuing
if [[ "$menuflag" = "TRUE" || "$menuflag" = "true" ]]
   then


    ((rc=99))
    while ((rc != 0))
      do
        [[ -e "$ddlFile" ]] || ((rc=4))
        case $rc in
          1) print "    Enter the database name:"
             read input
             [[ -n $input ]] && dbName=$input
             ;;

          2) print "    Enter the database server's userid:"
             read input
             [[ -n $input ]] && dbUser=$input
             ;;

          3) print "    Enter the database server's userid's password:"
             read input
             [[ -n $input ]] && dbUserPW=$input
             ;;

          4) print "    Enter the path and file name of the DDL file:"
             print "    This value must be correct before any other values can be changed."
             print "    Recommended value is the DDL file provided with the component"
             read input
             [[ -n $input ]] && ddlFile=$input
             ;;
             
          *)
            ;;
        esac

        if [[ -s $ddlFile ]]
        then
          displayGUI
        else    # request location of the ddl again
          print "    ERROR: Cannot find file $ddlFile"
          print "      ensure you include the path information to the DDL file"
          ((rc=4))
        fi

      done  # end of while loop
fi  # end of menuing block   

  #####################################################################
  # if a column needs to be set to a larger size,
  # simply edit the DDL file before running this script.
  # 
  # note that VARCHAR2 have a maximum size of 4000 bytes, so to extend
  # beyond that, you will have to switch to a different character type
  # regenerate the backend and redeploya.
  # see the Oracle SQL Reference.
  #####################################################################
  print "Preparing the database."

  sqlplus $dbUser/$dbUserPW@$dbName @$ddlFile

print ""
print "$0 is complete."
exit
