#!/usr/bin/ksh
#   begin_generated_IBM_prolog                                          
#                                                                       
#   prolog.pro.samp.telcosp                                                 
#   ******************************************************************  
#   IBM Sample Source Materials                                         
#                                                                       
#   Sample source materials are supplied As-Is.                         
#   No warranty is expressed or implied.                                
#                                                                       
#   Product(s): 5724-O05 soa                                            
#                                                                       
#   Copyright IBM Corp. 2000, 2009                                      
#                                                                       
#   The source code for this program supplied under the terms of the    
#   End User License Agreement (EULA) that accompanied this product.    
#   ******************************************************************  
#                                                                       
#   end_generated_IBM_prolog                                            

#------------------------------------------------------------------
# Create the IBM DB2 database tables
# Version: 1.7.5.15
#
# To debug this script change the first line to
# "#!/usr/bin/ksh -x" or "#!/usr/bin/ksh -v".
# You may also want to comment out any "clear" commands in the
# script.
#------------------------------------------------------------------

#------------------------------------------------------------------
# The DB2 instance id and connection port might be in /etc/services.
# Example:
#   db2cdb2inst1    50000/tcp   # Connection port for DB2 instance db2inst1
#------------------------------------------------------------------

#------------------------------------------------------------------
# Display information to user
#------------------------------------------------------------------

function displayUsage {

  # Note: INIT initialize mode is mutually exclusive from execute a DDL (data definition language) file mode
  #clear
  print "Usage: crtsrvDb2.sh dbServer dbPort dbLocal dbNodeName"
  print "                    dbName dbAlias dbLocale"
  print "                    dbAdmin dbAdminPW dbUser dbUserPW"
  print "                    INITorDDLFile infoflag"
  print ""
  print "Where:"
  print ""
  print "  dbServer    Database server hostname"
  print "              Recommended Value: fully qualified host name."
  print "  dbPort      Database server connection port"
  print "              Recommended Value: 50000"
  print "  dbLocal     Local Database"
  print "              Recommended Value: TRUE for local"              
  print "  dbNodeName  Remote Database Server Node Name"
  print "              Recommended Value: RDBSRV"
  print "  dbName      Database name"
  print "              Recommended Value: TWSS70"
  print "  dbAlias     Database alias name"
  print "              Recommended Value: TWSS70A"
  print "  dbLocale    The Database territory code"
  print "              Recommended Value: US"
  print "  dbAdmin     Database server administrator instance ID"
  print "              Recommended Value is db2inst1"
  print "  dbAdminPW   Database server administrator instance password"
  print "  dbUser      Database user ID"
  print "              Recommended Value is twssuser"
  print "  dbUserPW    Database user password"
  print "  INITorDDLFile  'INIT' to initialize or the path to DDL File"
  print "  infoflag    Display Information Flag"
  print "              Recommended Value: TRUE"
  print ""

} # end of function displayUsage

function displayInfo {

  #clear
  print ""
  print "  Database server hostname........................: " $dbServer
  print "  Database server connection port.................: " $dbPort
  print "  Local Database..................................: " $dbLocal
  print "  Remote Database Server Node Name................: " $dbNodeName
  print "  Database name...................................: " $dbName
  print "  Database alias..................................: " $dbAlias
  print "  Database locale.................................: " $dbLocale
  print "  Database administrator instance ID..............: " $dbAdmin
  print "  Database administrator instance password........: " $dbAdminPW
  print "  Database user ID................................: " $dbUser
  print "  Database user password..........................: " $dbUserPW
  print "  INIT or path to the DDL file....................: " $INITorDDLFile
  print ""
} # end of function displayInfo

function pause {
   read input
}

#------------------------------------------------------------------
# Program main code
#------------------------------------------------------------------

# process menu
dbServer=$1
dbPort=$2
dbLocal=$3
dbNodeName=$4
dbName=$5
dbAlias=$6
dbLocale=$7
dbAdmin=$8
dbAdminPW=$9
dbUser=${10}
dbUserPW=${11}
INITorDDLFile=${12}
infoflag=${13}

if [[ -z $infoflag ]]
   then
      displayUsage
      exit
fi 

if [[ -z $dbLocal ]]
   then
      displayUsage
      exit
fi

if [[ -z $dbServer ]]
   then
      displayUsage
      exit
fi

if [[ -z $dbNodeName ]]
   then
      displayUsage
      exit
fi

if [[ -z $dbPort ]]
   then
      displayUsage
      exit
fi

if [[ -z $dbName ]]
   then 
      displayUsage
      exit
fi

if [[ -z $dbAlias ]]
   then 
      displayUsage
      exit
fi

if [[ -z $dbLocale ]]
   then
      displayUsage
      exit
fi

if [[ "$infoflag" = "TRUE" || "$infoflag" = "true" ]]
   then
     displayInfo
fi     # end of menuing block

# now execute the stuff

if [[ "INIT" = "$INITorDDLFile" || "init" = "$INITorDDLFile" ]]
  then
     # Execute the then block if the DB2 server is local.
     # Execute the else block if the DB2 server is remote, as in a cluster.
     if [[ "TRUE" = "$dbLocal" || "true" = "$dbLocal" ]]
       then
         # local
         if [[ "$dbName" = "$dbAlias" ]]
           then
             db2 create database $dbName using codeset UTF-8 territory $dbLocale with \"WebSphere TWSS DB\"
           else 
             db2 uncatalog database $dbAlias
             db2 uncatalog node local
             db2 catalog local node local
             db2 create database $dbName using codeset UTF-8 territory $dbLocale with \"WebSphere TWSS DB\"
             db2 catalog database $dbName as $dbAlias at node local
         fi
       else
         # remote
         db2 uncatalog database $dbAlias
         db2 uncatalog node $dbNodeName
         db2 catalog tcpip node $dbNodeName remote $dbServer server $dbPort
         db2 attach to $dbNodeName user $dbAdmin using $dbAdminPW
         db2 create database $dbName using codeset UTF-8 territory $dbLocale with \"WebSphere TWSS DB\"
         db2 detach  
         db2 catalog database $dbName as $dbAlias at node $dbNodeName with \"WebSphere TWSS DB\"
     fi

     db2 connect to $dbAlias user $dbAdmin using $dbAdminPW
     if [[ "$dbAdmin" != "$dbUser" ]]
        then
           db2 grant DBADM on database to user $dbUser
     fi
     
     ########################################################################
     #
     #   All columns (except CLOBs and BLOBs) must fit within the page size
     #   (default is 4K).  So if you need to increase column sizes, you may
     #   have to place the table in a tablespace with a larger page size.
     #   See the DB2 Administrator Guide for a more detailed explaination of
     #   the design rules and the DB2 SQL Reference for details of the
     #   command syntax.
     #
     #   If the SRVPOOL OR SRVSPACE already exist you will get errors and that is ok.
     #
     #   ** create bufferpool using 8K.  You can also use 16K or 32K.
     db2 CREATE BUFFERPOOL SRVPOOL SIZE 250 PAGESIZE 8K
     db2 CREATE BUFFERPOOL PARLAYPOOL SIZE 250 PAGESIZE 16K
     #
     #   Terminate all access to the database before the SRVPOOL will be active.
     #   !Note! this appears no longer to be necessary, but maybe on older versions of DB2
     #
     #   *****  Important  ****  Important  ****  Important  ****  Important **
     #   ** The chosen path must be writable by the database end user's ID.
     #   ** The directory must be empty or have the same database in it.
     #
     line="db2 CREATE REGULAR TABLESPACE SRVSPACE PAGESIZE 8 K  MANAGED BY SYSTEM USING ('soatmp') EXTENTSIZE 32 OVERHEAD 24.1 PREFETCHSIZE 16 TRANSFERRATE 0.9 BUFFERPOOL SRVPOOL"
     $line
     line="db2 CREATE REGULAR TABLESPACE PARLAYSPACE PAGESIZE 16 K  MANAGED BY SYSTEM USING ('soatmp1') EXTENTSIZE 32 OVERHEAD 24.1 PREFETCHSIZE 16 TRANSFERRATE 0.9 BUFFERPOOL PARLAYPOOL"
     $line
     line="db2 CREATE TABLESPACE SCHED_TABLESPACE MANAGED BY SYSTEM USING( 'schedtmp' )"
     $line
     db2 CREATE SCHEMA ESBLOG
     db2 connect reset
     db2 terminate
     
     ########################################################################
  else
     #
     ########################################################################
     # Now create the database tables. See the comment above regarding row size.
     if [[ -r $INITorDDLFile ]]
        then
           db2 connect to $dbAlias user $dbUser using $dbUserPW

           # Tell DB2 to run the users DDL commands
           db2 -tvf $INITorDDLFile

           db2 connect reset
           db2 terminate
        else
          print "ERROR: The DDL file cannot be found or is not readable by this process.";
          exit
     fi
fi

print ""
print "= Note: ====================================================================="
print "  User "$dbUser" may have been granted DBADM authorities to database "$dbName"."
print ""
print "  You may want to revoke several of the authorities that have been granted."
print "  The user will require the authority necessary to access and update "$dbName"."
print ""
print "  To remove DBADM authority, issue the following commands:"
print "     db2 connect to "$dbAlias" user "$dbAdmin
print "     db2 revoke DBADM,LOAD,IMPLICIT_SCHEMA on database from "$dbUser
print "     db2 revoke BINDADD,CREATE_NOT_FENCED on database from "$dbUser
print "     db2 terminate"
print ""
print ""

exit
