#!/usr/bin/ksh
#   begin_generated_IBM_prolog                                          
#                                                                       
#   prolog.pro.samp.telcosp                                                 
#   ******************************************************************  
#   IBM Sample Source Materials                                         
#                                                                       
#   Sample source materials are supplied As-Is.                         
#   No warranty is expressed or implied.                                
#                                                                       
#   Product(s): 5724-O05                                                
#                                                                       
#   Copyright IBM Corp. 2000, 2009                                      
#                                                                       
#   The source code for this program supplied under the terms of the    
#   End User License Agreement (EULA) that accompanied this product.    
#   ******************************************************************  
#                                                                       
#   end_generated_IBM_prolog                                            

#------------------------------------------------------------------
# Create the Oracle database tables
# Version: 1.1.2.14
#
# To debug this script change the first line to
# "#!/usr/bin/ksh -x" or "#!/usr/bin/ksh -v".
# You may also want to comment out any "clear" commands in the
# script.
#------------------------------------------------------------------

#------------------------------------------------------------------
# Display information to user
#------------------------------------------------------------------

function displayUsage {

  #  Note: INIT initialize mode is mutually exclusive from execute a DDL (data definition language) file mode
  #clear
  print "Usage: crtsrvOra.sh dbName dbAdmin dbAdminPW dbUser dbUserPW INITorDDLFile infoflag"
  print ""
  print "Where:"
  print ""
  print "  dbName        Database name"
  print "                Recommended Value: TWSS70"
  print "  dbAdmin       Database administrator ID"
  print "                Recommended Value: SYSTEM"
  print "  dbAdminPW     Database administrator password"
  print "  dbUser        Database user ID"
  print "                Recommended Value: twssuser"
  print "  dbUserPW      Database user password"
  print "  INITorDDLFile 'INIT' to initialize or Path to DDL File"
  print "                Recommended Value: INIT"
  print "  infoflag      Display Information Flag"
  print "                Recommended Value: TRUE"
  print ""

} # end of function displayUsage


function displayInfo {

  #clear
  print ""
  print "   Database name........... ....................: " $dbName
  print "   Database administrator ID....................: " $dbAdmin
  print "   Database administrator password..............: " $dbAdminPW
  print "   Database userid..............................: " $dbUser
  print "   Database userid password.....................: " $dbUserPW
  print "   Data Definition file.........................: " $INITorDDLFile
  print ""
  pause
}

function pause {
   read input
}

#------------------------------------------------------------------
# Program main code
#------------------------------------------------------------------

# initialize command line parameters

dbName=$1
dbAdmin=$2
dbAdminPW=$3
dbUser=$4
dbUserPW=$5
INITorDDLFile=$6
infoflag=$7

# handle infoflag not specified
if [[ -z $infoflag ]]
   then
      displayUsage
      exit
fi 

if [[ -z $dbName ]]
   then
      displayUsage
      exit
fi

if [[ -z $dbAdmin ]]
   then
      displayUsage
      exit
fi

if [[ -z $dbAdminPW ]]
   then
      displayUsage
      exit
fi

if [[ -z $dbUser ]]
   then
      displayUsage
      exit
fi

if [[ -z $dbUserPW ]]
   then
      displayUsage
      exit
fi

if [[ -z $INITorDDLFile ]]
   then
      displayUsage
      exit
fi

# execute menuing
if [[ "$infoflag" = "TRUE" || "$infoflag" = "true" ]]
   then
      displayInfo
fi  # end of menuing block

export ORACLE_SID=$dbName

if [[ "INIT" = "$INITorDDLFile" || "init" = "$INITorDDLFile" ]]
  then
     echo create user $dbUser identified by $dbUserPW profile default";" > crtsrvOra.ddl
     echo grant connect, resource, create table, create view, dba to $dbUser";" >> crtsrvOra.ddl
     echo create user ESBLOG identified by $dbUserPW profile default";" >> crtsrvOra.ddl
     echo grant connect, resource, create table, create view, dba to ESBLOG";" >> crtsrvOra.ddl
     echo CREATE TABLESPACE SCHED_TABLESPACE DATAFILE "'"schedtmp_$dbName.dbf"'" SIZE 5M AUTOEXTEND ON NEXT 1M MAXSIZE UNLIMITED";" >> crtsrvOra.ddl
     echo commit";" >> crtsrvOra.ddl
     echo quit";" >> crtsrvOra.ddl
     sqlplus $dbAdmin/$dbAdminPW as SYSDBA@$dbName @crtsrvOra.ddl
     rm -rf crtsrvOra.ddl
  else
     if [[ -r $INITorDDLFile ]]
        then
           sqlplus $dbUser/$dbUserPW@$dbName @$INITorDDLFile
        else
          print "ERROR: The DDL file cannot be found or is not readable by this process.";
          exit
     fi
fi     

exit



